==> estateplat-common-1.2.4-20221226.020916-1132-sources.jar: cn/gtmap/estateplat/model/server/core/BdcHmd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/5/7
 * @description 不动产黑名单
 */
@Table(name = "bdc_hmd")
public class BdcHmd {
    /**
     * 主键
     */
    @Id
    private String id;
    /**
     * 限制人名称
     */
    private String xzrmc;
    /**
     * 限制人证件号码
     */
    private String xzrzjhm;
    /**
     * 限制类型
     */
    private String xzlx;
    /**
     * 限制原因
     */
    private String xzyy;
    /**
     * 代理人名称
     */
    private String dlrmc;
    /**
     * 代理人联系电话
     */
    private String dlrlxdh;
    /**
     * 录入人
     */
    private String lrr;
    /**
     * 录入时间
     */
    private Date lrsj;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getXzrmc() {
        return xzrmc;
    }

    public void setXzrmc(String xzrmc) {
        this.xzrmc = xzrmc;
    }

    public String getXzrzjhm() {
        return xzrzjhm;
    }

    public void setXzrzjhm(String xzrzjhm) {
        this.xzrzjhm = xzrzjhm;
    }

    public String getXzlx() {
        return xzlx;
    }

    public void setXzlx(String xzlx) {
        this.xzlx = xzlx;
    }

    public String getXzyy() {
        return xzyy;
    }

    public void setXzyy(String xzyy) {
        this.xzyy = xzyy;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getDlrlxdh() {
        return dlrlxdh;
    }

    public void setDlrlxdh(String dlrlxdh) {
        this.dlrlxdh = dlrlxdh;
    }

    public String getLrr() {
        return lrr;
    }

    public void setLrr(String lrr) {
        this.lrr = lrr;
    }

    public Date getLrsj() {
        return lrsj;
    }

    public void setLrsj(Date lrsj) {
        this.lrsj = lrsj;
    }
}

==> estateplat-common-1.2.4-20240820.030506-1250-sources.jar: cn/gtmap/estateplat/model/server/core/BdcHmd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2022/5/7
 * @description 不动产黑名单
 */
@Table(name = "bdc_hmd")
public class BdcHmd {
    /**
     * 主键
     */
    @Id
    private String id;
    /**
     * 限制人名称
     */
    private String xzrmc;
    /**
     * 限制人证件号码
     */
    private String xzrzjhm;
    /**
     * 限制类型
     */
    private String xzlx;
    /**
     * 限制原因
     */
    private String xzyy;
    /**
     * 代理人名称
     */
    private String dlrmc;
    /**
     * 代理人联系电话
     */
    private String dlrlxdh;
    /**
     * 录入人
     */
    private String lrr;
    /**
     * 录入时间
     */
    private Date lrsj;
    /**
     * 限制方式
     */
    private String xzfs;
    /**
     * 权利人类型
     */
    private String qlrlx;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getXzrmc() {
        return xzrmc;
    }

    public void setXzrmc(String xzrmc) {
        this.xzrmc = xzrmc;
    }

    public String getXzrzjhm() {
        return xzrzjhm;
    }

    public void setXzrzjhm(String xzrzjhm) {
        this.xzrzjhm = xzrzjhm;
    }

    public String getXzlx() {
        return xzlx;
    }

    public void setXzlx(String xzlx) {
        this.xzlx = xzlx;
    }

    public String getXzyy() {
        return xzyy;
    }

    public void setXzyy(String xzyy) {
        this.xzyy = xzyy;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getDlrlxdh() {
        return dlrlxdh;
    }

    public void setDlrlxdh(String dlrlxdh) {
        this.dlrlxdh = dlrlxdh;
    }

    public String getLrr() {
        return lrr;
    }

    public void setLrr(String lrr) {
        this.lrr = lrr;
    }

    public Date getLrsj() {
        return lrsj;
    }

    public void setLrsj(Date lrsj) {
        this.lrsj = lrsj;
    }

    public String getXzfs() {
        return xzfs;
    }

    public void setXzfs(String xzfs) {
        this.xzfs = xzfs;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }
}
